import { Headers, Query } from '../jumbo';
import { JumboObject } from '../base/jumboObject';
import { ProductModel } from './productModel';
export declare class Product extends JumboObject {
    /**
     * Gets product from ID
     * @param productId Product ID
     */
    getProductFromId(productId: string, headers?: Headers, query?: Query): Promise<ProductModel>;
    /**
     * Get products from given product name
     * @param productName Product name to search for
     * @param offset Offset in search (default 0)
     * @param limit Amount of products returned (default 10)
     * @param filter Filters (from ProductFilter)
     * @param sort Sort options as defined in ./productModel
     */
    getProductsFromName(productName: string, offset?: number, limit?: number, filter?: ProductFilter, sort?: ProductSortOptions, headers?: Headers, query?: Query): Promise<ProductModel[]>;
    /**
     * Shortcut function to get the first product when searching for name
     * @param productName Product name to search for
     * @param sort Sort options as defined in ./productModel
     */
    getFirstProductFromName(productName: string, sort?: ProductSortOptions, headers?: Headers, query?: Query): Promise<ProductModel>;
    /**
     * Translates the product filters to a usable query
     */
    private translateProductFilterToQuery;
}
/**
 * The different sort options for products
 */
export declare enum ProductSortOptions {
    POPULAR = "P_Sales|1",
    PRICE_ASC = "P_Price|0",
    PRICE_DESC = "P_Price|1",
    ALPHAB_ASC = "P_Title|0",
    ALPHAB_DESC = "P_Title|1",
    PER_WEIGHT_MEASURE = "pricePerWeightMeasure|0"
}
/**
 * Currently available filters
 * diet: any dietary restrictions, can be filtered from ProductDietFilter
 * allergens: any allergens that are not allowed, can be filtered from ProductAllergenFilter
 * other: any other restrictions, in the form of an array of numbers
 */
export interface ProductFilter {
    diet?: ProductDietFilter[];
    allergens?: ProductAllergenFilter[];
    other?: number[];
}
export declare enum ProductDietFilter {
    Bio = 4294960557,
    LactoseIntolerant = 4294960541,
    Vegan = 204294960595,
    GlutenIntolerant = 4294960639,
    NoAddedSugar = 4294960544,
    NoAddedSalt = 4294960120,
    Vegetarian = 4294960623,
    LowFat = 4294960596,
    LowSugar = 4294952996,
    NoSugar = 4294960685,
    NoFat = 4294960453,
    FatPoor = 4294926481,
    Halal = 4294960615,
    Kosher = 4294960433
}
export declare enum ProductAllergenFilter {
    Lactose = 4294960577,
    Gluten = 4294960640,
    Diary = 4294960597,
    Milk = 4294960576,
    Soy = 4294960064,
    Peanuts = 4294960574,
    Nuts = 4294960575,
    Wheat = 4294960573,
    Eggs = 4294960578
}
